@@ -156,11 +156,11 @@ COND_REU_NOT_AO = [ u'[%s]르' % V_NOT_A_O, u'[%s][%s]르' % (V_NOT_A_O, T_ALL)
 # 
 # '으' 음절 앞에 오는 음절이 있는 경우 그 음절의 모음이 양성모음이냐
 # 음성모음이냐에 따라 어미의 '어/아'가 결정되는데, '끄다', '뜨다',
-# '쓰다', '크다'같은 으불규칙용언의 경우 앞의 음절이 없으면서 '어'가
-# 붙는다. 그래서 aff 파일의 같은 규칙 안에서 조건으로 정의할 수가
-# 없다. (aff 파일에서 쓸 수 있는 제한된 정규식으로는 으 앞에 음절이
-# 없다는 걸 정의할 수가 없다.) 그러므로 '끄다', '뜨다', '쓰다',
-# '크다'는 항상 별도 규칙으로 만든다.
+# '쓰다', '트다', '크다'같은 으불규칙용언의 경우 앞의 음절이 없으면서
+# '어'가 붙는다. 그래서 aff 파일의 같은 규칙 안에서 조건으로 정의할
+# 수가 없다. (aff 파일에서 쓸 수 있는 제한된 정규식으로는 으 앞에
+# 음절이 없다는 걸 정의할 수가 없다.) 그러므로 '끄다', '뜨다', '쓰다',
+# '트다', '크다'는 항상 별도 규칙으로 만든다.
 
 # 앞에 ㅏ/ㅗ 모음의 음절
 COND_EU_AO = [ u'[%s][%s]%s' % (V_A_O, L_ALL, V_EU),
@@ -295,12 +295,12 @@ groups['-었-'] = [
     { 'rules': [[u'-' + V_A + T_SSANGSIOS + u'-', COND_EU_AO, V_EU],
                 [u'-' + V_EO + T_SSANGSIOS + u'-', COND_EU_NOT_AO, V_EU]],
       'after': ['#용언'],
-      'notafter': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*크다$'],
+      'notafter': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*트다$', '^.*크다$'],
       'cond': ['#으불규칙'],
     },
     # 으불규칙 예외 '끄다', '뜨다', '쓰다', '크다'
     { 'rules': [[u'-' + V_EO + T_SSANGSIOS + u'-', V_EU, V_EU]],
-      'after': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*크다$'],
+      'after': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*트다$', '^.*크다$'],
       'cond': ['#으불규칙'],
     },
 ]
@@ -409,12 +409,12 @@ groups['-어'] = [
     { 'rules': [[u'-' + V_A, COND_EU_AO, V_EU],
                 [u'-' + V_EO, COND_EU_NOT_AO, V_EU]],
       'after': ['#용언'],
-      'notafter': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*크다$'],
+      'notafter': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*트다$', '^.*크다$'],
       'cond': ['#으불규칙'],
     },
     # 으불규칙 예외 '끄다', '뜨다', '크다', '쓰다'
     { 'rules': [[u'-' + V_EO, V_EU, V_EU]],
-      'after': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*크다$'],
+      'after': ['^.*끄다$', '^.*뜨다$', '^.*쓰다$', '^.*트다$', '^.*크다$'],
       'cond': ['#으불규칙'],
     },
 ]
